--UPD-5843
--Replace <LOGIN> with the login the application will use to access the database.
--BEGIN SubsidiaryHierarchyReport

if exists
  (select name from sysobjects
   where name = 'SubsidiaryHierarchyReport'
   and type = 'P')
  drop procedure SubsidiaryHierarchyReport
go


CREATE PROCEDURE SubsidiaryHierarchyReport
 @params varchar(100)
AS

--To run this procedure: exec SubsidiaryHierarchyReport '10,002.00;6/1/2013;15.00;true'

DECLARE @entityEID int;
DECLARE @asOfDate datetime;
DECLARE @numLevels int;
DECLARE @showALL bit;
DECLARE @showAffiliates bit;

SET @entityEID = REPLACE(REPLACE((SELECT dbo.SplitSingle(@params, ';', 1)), ',', ''), '.00', '');
SET @asOfDate = (SELECT dbo.SplitSingle(@params, ';', 2));
SET @numLevels = REPLACE((SELECT dbo.SplitSingle(@params, ';', 3)), '.00', '');
SET @showALL = CASE WHEN (SELECT dbo.SplitSingle(@params, ';', 4)) = 'True' THEN 1 ELSE 0 END;
SET @showAffiliates = CASE WHEN (SELECT dbo.SplitSingle(@params, ';', 5)) = 'True' THEN 1 ELSE 0 END;

--exec SubsidiaryHierarchyReport '10001.00;6/1/2000;5;false;false'
SET NOCOUNT ON

CREATE TABLE #SubsHierarchyOwnership
(
	Ownership_ID int,
	Entity_EID int,
	Name varchar(150),
	Type_CD varchar(40),
	FederalNumber varchar(50),
	Owner_EID int,
	StartDate datetime,
	EndDate datetime,
	UnitsHeld numeric(23,7),
	EquityPercent numeric(10,6),
	Comments varchar(max),
	JurisdictionName varchar(40),
	AddressVal varchar(700)
)
CREATE CLUSTERED INDEX IDX_C_tmpEntity_OwnershipID ON #SubsHierarchyOwnership(Ownership_ID);

INSERT INTO #SubsHierarchyOwnership
SELECT
 o.Ownership_ID, e.Entity_EID, e.Name, e.Type_CD, e.FederalNumber, o.Owner_EID,
 CASE 
	WHEN ISNULL(o.startdate, '12/30/2999') = '12/30/2999' THEN DateAdd(dd, -1, @asOfDate) 
 ELSE o.StartDate
 END as startdate,
 CASE
	WHEN @showALL = 1 THEN DateAdd(dd, 1, @asOfDate)
	WHEN o.endDate = '12/30/2999' THEN DateAdd(dd, 1, @asOfDate) 
 ELSE o.EndDate 
 END as endDate,
 o.UnitsHeld, o.equitypercent, convert(varchar(max), l.Comments) as Comments, j.JurisdictionName,
 (SELECT top 1 Address1+ISNULL('|'+Address2, '')+ISNULL('|'+Address3, '')+ISNULL('|'+Address4, '')+ISNULL('|'+City+', '+StateProvince+ISNULL(' '+Zip, '')+ISNULL(' '+Country, ''), '') as AddressVal FROM Address a JOIN Entity_Address ea on ea.Address_ID = a.Address_ID WHERE ea.Entity_EID = e.Entity_EID and (ea.IsPrimary='T' or ea.AddressType_CD = 'Primary')) as AddressVal
FROM Ownership o with (NOLOCK)
 JOIN Entity e with (NOLOCK) on e.Entity_EID = o.Company_ID
 LEFT JOIN LongComments l with (NOLOCK) on l.Comments_ID = o.Comments_ID 
 LEFT JOIN Registration r with (NOLOCK) on r.Registration_ID = dbo.GetFormationRegistrationID(e.Entity_EID, ''+convert(varchar(12), @asOfDate, 101)+'') 
 LEFT JOIN Jurisdiction j with (NOLOCK) on j.Jurisdiction_ID = r.Jurisdiction_ID
WHERE (o.StartDate <= @asOfDate or ISNULL(o.StartDate, '12/30/2999') = '12/30/2999')
 and (@showALL = 1 OR (ISNULL(o.EndDate, '12/30/2999') = '12/30/2999' or o.EndDate >= @asOfDate))
 and (@showAffiliates = 1 OR ISNULL(e.Affiliate, 'F') = 'T');

SELECT DISTINCT
 e.Entity_EID, e.Name,
 l1.Ownership_ID as Ownership_ID1,
 l2.Ownership_ID as Ownership_ID2,
 l3.Ownership_ID as Ownership_ID3,
 l4.Ownership_ID as Ownership_ID4,
 l5.Ownership_ID as Ownership_ID5,
 l6.Ownership_ID as Ownership_ID6,
 l7.Ownership_ID as Ownership_ID7,
 l8.Ownership_ID as Ownership_ID8,
 l9.Ownership_ID as Ownership_ID9,
 l10.Ownership_ID as Ownership_ID10,
 l11.Ownership_ID as Ownership_ID11,
 l12.Ownership_ID as Ownership_ID12,
 l13.Ownership_ID as Ownership_ID13,
 l14.Ownership_ID as Ownership_ID14,
 l15.Ownership_ID as Ownership_ID15
INTO #SubsHierarchyTree
FROM Entity e
 LEFT JOIN #SubsHierarchyOwnership l1 with (NoLock) on l1.Owner_EID = e.Entity_EID and l1.Entity_EID <> e.Entity_EID
 LEFT JOIN #SubsHierarchyOwnership l2 with (NoLock) on @numLevels > 1 and l2.Owner_EID = l1.Entity_EID and l2.Entity_EID not in (e.Entity_EID, l1.Entity_EID) 
		and l2.Owner_EID not in (l1.Owner_EID)
 LEFT JOIN #SubsHierarchyOwnership l3 with (NoLock) on @numLevels > 2 and l3.Owner_EID = l2.Entity_EID and l3.Entity_EID not in (e.Entity_EID, l1.Entity_EID, l2.Entity_EID)
		and l3.Owner_EID not in (l1.Owner_EID, l2.Owner_EID)
 LEFT JOIN #SubsHierarchyOwnership l4 with (NoLock) on @numLevels > 3 and l4.Owner_EID = l3.Entity_EID and l4.Entity_EID not in (e.Entity_EID, l1.Entity_EID, l2.Entity_EID ,l3.Entity_EID)
		and l4.Owner_EID not in (l1.Owner_EID, l2.Owner_EID, l3.Owner_EID)
 LEFT JOIN #SubsHierarchyOwnership l5 with (NoLock) on @numLevels > 4 and l5.Owner_EID = l4.Entity_EID and l5.Entity_EID not in (e.Entity_EID, l1.Entity_EID, l2.Entity_EID ,l3.Entity_EID, l4.Entity_EID)
		and l5.Owner_EID not in (l1.Owner_EID, l2.Owner_EID, l3.Owner_EID, l4.Owner_EID)
 LEFT JOIN #SubsHierarchyOwnership l6 with (NoLock) on @numLevels > 5 and l6.Owner_EID = l5.Entity_EID and l6.Entity_EID not in (e.Entity_EID, l1.Entity_EID, l2.Entity_EID ,l3.Entity_EID, l4.Entity_EID, l5.Entity_EID)
		and l6.Owner_EID not in (l1.Owner_EID, l2.Owner_EID, l3.Owner_EID, l4.Owner_EID, l5.Owner_EID)
 LEFT JOIN #SubsHierarchyOwnership l7 with (NoLock) on @numLevels > 6 and l7.Owner_EID = l6.Entity_EID and l7.Entity_EID not in (e.Entity_EID, l1.Entity_EID, l2.Entity_EID ,l3.Entity_EID, l4.Entity_EID, l5.Entity_EID, l6.Entity_EID)
		and l7.Owner_EID not in (l1.Owner_EID, l2.Owner_EID, l3.Owner_EID, l4.Owner_EID, l5.Owner_EID, l6.Owner_EID)
 LEFT JOIN #SubsHierarchyOwnership l8 with (NoLock) on @numLevels > 7 and l8.Owner_EID = l7.Entity_EID and l8.Entity_EID not in (e.Entity_EID, l1.Entity_EID, l2.Entity_EID ,l3.Entity_EID, l4.Entity_EID, l5.Entity_EID, l6.Entity_EID, l7.Entity_EID)
		and l8.Owner_EID not in (l1.Owner_EID, l2.Owner_EID, l3.Owner_EID, l4.Owner_EID, l5.Owner_EID, l6.Owner_EID, l7.Owner_EID)
 LEFT JOIN #SubsHierarchyOwnership l9 with (NoLock) on @numLevels > 8 and l9.Owner_EID = l8.Entity_EID and l9.Entity_EID not in (e.Entity_EID, l1.Entity_EID, l2.Entity_EID ,l3.Entity_EID, l4.Entity_EID, l5.Entity_EID, l6.Entity_EID, l7.Entity_EID, l8.Entity_EID)
		and l9.Owner_EID not in (l1.Owner_EID, l2.Owner_EID, l3.Owner_EID, l4.Owner_EID, l5.Owner_EID, l6.Owner_EID, l7.Owner_EID, l8.Owner_EID)
 LEFT JOIN #SubsHierarchyOwnership l10 with (NoLock) on @numLevels > 9 and l10.Owner_EID = l9.Entity_EID and l10.Entity_EID not in (e.Entity_EID, l1.Entity_EID, l2.Entity_EID ,l3.Entity_EID, l4.Entity_EID, l5.Entity_EID, l6.Entity_EID, l7.Entity_EID, l8.Entity_EID, l9.Entity_EID)
		and l10.Owner_EID not in (l1.Owner_EID, l2.Owner_EID, l3.Owner_EID, l4.Owner_EID, l5.Owner_EID, l6.Owner_EID, l7.Owner_EID, l8.Owner_EID, l9.Owner_EID)
 LEFT JOIN #SubsHierarchyOwnership l11 with (NoLock) on @numLevels > 10 and l11.Owner_EID = l10.Entity_EID and l11.Entity_EID not in (e.Entity_EID, l1.Entity_EID, l2.Entity_EID ,l3.Entity_EID, l4.Entity_EID, l5.Entity_EID, l6.Entity_EID, l7.Entity_EID, l8.Entity_EID, l9.Entity_EID, l10.Entity_EID)
		and l11.Owner_EID not in (l1.Owner_EID, l2.Owner_EID, l3.Owner_EID, l4.Owner_EID, l5.Owner_EID, l6.Owner_EID, l7.Owner_EID, l8.Owner_EID, l9.Owner_EID, l10.Owner_EID)
 LEFT JOIN #SubsHierarchyOwnership l12 with (NoLock) on @numLevels > 11 and l12.Owner_EID = l11.Entity_EID and l12.Entity_EID not in (e.Entity_EID, l1.Entity_EID, l2.Entity_EID ,l3.Entity_EID, l4.Entity_EID, l5.Entity_EID, l6.Entity_EID, l7.Entity_EID, l8.Entity_EID, l9.Entity_EID, l10.Entity_EID, l11.Entity_EID)
		and l12.Owner_EID not in (l1.Owner_EID, l2.Owner_EID, l3.Owner_EID, l4.Owner_EID, l5.Owner_EID, l6.Owner_EID, l7.Owner_EID, l8.Owner_EID, l9.Owner_EID, l10.Owner_EID, l11.Owner_EID)
 LEFT JOIN #SubsHierarchyOwnership l13 with (NoLock) on @numLevels > 12 and l13.Owner_EID = l12.Entity_EID and l13.Entity_EID not in (e.Entity_EID, l1.Entity_EID, l2.Entity_EID ,l3.Entity_EID, l4.Entity_EID, l5.Entity_EID, l6.Entity_EID, l7.Entity_EID, l8.Entity_EID, l9.Entity_EID, l10.Entity_EID, l11.Entity_EID, l12.Entity_EID)
		and l13.Owner_EID not in (l1.Owner_EID, l2.Owner_EID, l3.Owner_EID, l4.Owner_EID, l5.Owner_EID, l6.Owner_EID, l7.Owner_EID, l8.Owner_EID, l9.Owner_EID, l10.Owner_EID, l11.Owner_EID, l12.Owner_EID)
 LEFT JOIN #SubsHierarchyOwnership l14 with (NoLock) on @numLevels > 13 and l14.Owner_EID = l13.Entity_EID and l14.Entity_EID not in (e.Entity_EID, l1.Entity_EID, l2.Entity_EID ,l3.Entity_EID, l4.Entity_EID, l5.Entity_EID, l6.Entity_EID, l7.Entity_EID, l8.Entity_EID, l9.Entity_EID, l10.Entity_EID, l11.Entity_EID, l12.Entity_EID, l13.Entity_EID)
		and l14.Owner_EID not in (l1.Owner_EID, l2.Owner_EID, l3.Owner_EID, l4.Owner_EID, l5.Owner_EID, l6.Owner_EID, l7.Owner_EID, l8.Owner_EID, l9.Owner_EID, l10.Owner_EID, l11.Owner_EID, l12.Owner_EID, l13.Owner_EID)
 LEFT JOIN #SubsHierarchyOwnership l15 with (NoLock) on @numLevels > 14 and l15.Owner_EID = l14.Entity_EID and l15.Entity_EID not in (e.Entity_EID, l1.Entity_EID, l2.Entity_EID ,l3.Entity_EID, l4.Entity_EID, l5.Entity_EID, l6.Entity_EID, l7.Entity_EID, l8.Entity_EID, l9.Entity_EID, l10.Entity_EID, l11.Entity_EID, l12.Entity_EID, l13.Entity_EID, l14.Entity_EID)
		and l15.Owner_EID not in (l1.Owner_EID, l2.Owner_EID, l3.Owner_EID, l4.Owner_EID, l5.Owner_EID, l6.Owner_EID, l7.Owner_EID, l8.Owner_EID, l9.Owner_EID, l10.Owner_EID, l11.Owner_EID, l12.Owner_EID, l13.Owner_EID, l14.Owner_EID)
WHERE e.Entity_EID = @entityEID;
 
SELECT t.Entity_EID, t.Name,
 e1.Entity_EID as Entity_EID1, e1.Name as Name1, e1.Type_CD as Type_CD1, e1.FederalNumber as FederalNumber1, e1.Owner_EID as Owner_EID1, e1.UnitsHeld as UnitsHeld1, e1.EquityPercent as EquityPercent1, ISNULL(e1.Comments, '') as Comments1, e1.JurisdictionName as Jurisdiction1, e1.AddressVal as Address1,
 e2.Entity_EID as Entity_EID2, e2.Name as Name2, e2.Type_CD as Type_CD2, e2.FederalNumber as FederalNumber2, e2.Owner_EID as Owner_EID2, e2.UnitsHeld as UnitsHeld2, e2.EquityPercent as EquityPercent2, ISNULL(e2.Comments, '') as Comments2, e2.JurisdictionName as Jurisdiction2, e2.AddressVal as Address2,
 e3.Entity_EID as Entity_EID3, e3.Name as Name3, e3.Type_CD as Type_CD3, e3.FederalNumber as FederalNumber3, e3.Owner_EID as Owner_EID3, e3.UnitsHeld as UnitsHeld3, e3.EquityPercent as EquityPercent3, ISNULL(e3.Comments, '') as Comments3, e3.JurisdictionName as Jurisdiction3, e3.AddressVal as Address3,
 e4.Entity_EID as Entity_EID4, e4.Name as Name4, e4.Type_CD as Type_CD4, e4.FederalNumber as FederalNumber4, e4.Owner_EID as Owner_EID4, e4.UnitsHeld as UnitsHeld4, e4.EquityPercent as EquityPercent4, ISNULL(e4.Comments, '') as Comments4, e4.JurisdictionName as Jurisdiction4, e4.AddressVal as Address4,
 e5.Entity_EID as Entity_EID5, e5.Name as Name5, e5.Type_CD as Type_CD5, e5.FederalNumber as FederalNumber5, e5.Owner_EID as Owner_EID5, e5.UnitsHeld as UnitsHeld5, e5.EquityPercent as EquityPercent5, ISNULL(e5.Comments, '') as Comments5, e5.JurisdictionName as Jurisdiction5, e5.AddressVal as Address5,
 e6.Entity_EID as Entity_EID6, e6.Name as Name6, e6.Type_CD as Type_CD6, e6.FederalNumber as FederalNumber6, e6.Owner_EID as Owner_EID6, e6.UnitsHeld as UnitsHeld6, e6.EquityPercent as EquityPercent6, ISNULL(e6.Comments, '') as Comments6, e6.JurisdictionName as Jurisdiction6, e6.AddressVal as Address6,
 e7.Entity_EID as Entity_EID7, e7.Name as Name7, e7.Type_CD as Type_CD7, e7.FederalNumber as FederalNumber7, e7.Owner_EID as Owner_EID7, e7.UnitsHeld as UnitsHeld7, e7.EquityPercent as EquityPercent7, ISNULL(e7.Comments, '') as Comments7, e7.JurisdictionName as Jurisdiction7, e7.AddressVal as Address7,
 e8.Entity_EID as Entity_EID8, e8.Name as Name8, e8.Type_CD as Type_CD8, e8.FederalNumber as FederalNumber8, e8.Owner_EID as Owner_EID8, e8.UnitsHeld as UnitsHeld8, e8.EquityPercent as EquityPercent8, ISNULL(e8.Comments, '') as Comments8, e8.JurisdictionName as Jurisdiction8, e8.AddressVal as Address8,
 e9.Entity_EID as Entity_EID9, e9.Name as Name9, e9.Type_CD as Type_CD9, e9.FederalNumber as FederalNumber9, e9.Owner_EID as Owner_EID9, e9.UnitsHeld as UnitsHeld9, e9.EquityPercent as EquityPercent9, ISNULL(e9.Comments, '') as Comments9, e9.JurisdictionName as Jurisdiction9, e9.AddressVal as Address9,
 e10.Entity_EID as Entity_EID10, e10.Name as Name10, e10.Type_CD as Type_CD10, e10.FederalNumber as FederalNumber10, e10.Owner_EID as Owner_EID10, e10.UnitsHeld as UnitsHeld10, e10.EquityPercent as EquityPercent10, ISNULL(e10.Comments, '') as Comments10, e10.JurisdictionName as Jurisdiction10, e10.AddressVal as Address10,
 e11.Entity_EID as Entity_EID11, e11.Name as Name11, e11.Type_CD as Type_CD11, e11.FederalNumber as FederalNumber11, e11.Owner_EID as Owner_EID11, e11.UnitsHeld as UnitsHeld11, e11.EquityPercent as EquityPercent11, ISNULL(e11.Comments, '') as Comments11, e11.JurisdictionName as Jurisdiction11, e11.AddressVal as Address11,
 e12.Entity_EID as Entity_EID12, e12.Name as Name12, e12.Type_CD as Type_CD12, e12.FederalNumber as FederalNumber12, e12.Owner_EID as Owner_EID12, e12.UnitsHeld as UnitsHeld12, e12.EquityPercent as EquityPercent12, ISNULL(e12.Comments, '') as Comments12, e12.JurisdictionName as Jurisdiction12, e12.AddressVal as Address12,
 e13.Entity_EID as Entity_EID13, e13.Name as Name13, e13.Type_CD as Type_CD13, e13.FederalNumber as FederalNumber13, e13.Owner_EID as Owner_EID13, e13.UnitsHeld as UnitsHeld13, e13.EquityPercent as EquityPercent13, ISNULL(e13.Comments, '') as Comments13, e13.JurisdictionName as Jurisdiction13, e13.AddressVal as Address13,
 e14.Entity_EID as Entity_EID14, e14.Name as Name14, e14.Type_CD as Type_CD14, e14.FederalNumber as FederalNumber14, e14.Owner_EID as Owner_EID14, e14.UnitsHeld as UnitsHeld14, e14.EquityPercent as EquityPercent14, ISNULL(e14.Comments, '') as Comments14, e14.JurisdictionName as Jurisdiction14, e14.AddressVal as Address14,
 e15.Entity_EID as Entity_EID15, e15.Name as Name15, e15.Type_CD as Type_CD15, e15.FederalNumber as FederalNumber15, e15.Owner_EID as Owner_EID15, e15.UnitsHeld as UnitsHeld15, e15.EquityPercent as EquityPercent15, ISNULL(e15.Comments, '') as Comments15, e15.JurisdictionName as Jurisdiction15, e15.AddressVal as Address15
FROM #SubsHierarchyTree t
 LEFT JOIN #SubsHierarchyOwnership e1 with (NOLOCK) on e1.Ownership_ID = t.Ownership_ID1
 LEFT JOIN #SubsHierarchyOwnership e2 with (NOLOCK) on e2.Ownership_ID = t.Ownership_ID2
 LEFT JOIN #SubsHierarchyOwnership e3 with (NOLOCK) on e3.Ownership_ID = t.Ownership_ID3
 LEFT JOIN #SubsHierarchyOwnership e4 with (NOLOCK) on e4.Ownership_ID = t.Ownership_ID4
 LEFT JOIN #SubsHierarchyOwnership e5 with (NOLOCK) on e5.Ownership_ID = t.Ownership_ID5
 LEFT JOIN #SubsHierarchyOwnership e6 with (NOLOCK) on e6.Ownership_ID = t.Ownership_ID6
 LEFT JOIN #SubsHierarchyOwnership e7 with (NOLOCK) on e7.Ownership_ID = t.Ownership_ID7
 LEFT JOIN #SubsHierarchyOwnership e8 with (NOLOCK) on e8.Ownership_ID = t.Ownership_ID8
 LEFT JOIN #SubsHierarchyOwnership e9 with (NOLOCK) on e9.Ownership_ID = t.Ownership_ID9
 LEFT JOIN #SubsHierarchyOwnership e10 with (NOLOCK) on e10.Ownership_ID = t.Ownership_ID10
 LEFT JOIN #SubsHierarchyOwnership e11 with (NOLOCK) on e11.Ownership_ID = t.Ownership_ID11
 LEFT JOIN #SubsHierarchyOwnership e12 with (NOLOCK) on e12.Ownership_ID = t.Ownership_ID12
 LEFT JOIN #SubsHierarchyOwnership e13 with (NOLOCK) on e13.Ownership_ID = t.Ownership_ID13
 LEFT JOIN #SubsHierarchyOwnership e14 with (NOLOCK) on e14.Ownership_ID = t.Ownership_ID14
 LEFT JOIN #SubsHierarchyOwnership e15 with (NOLOCK) on e15.Ownership_ID = t.Ownership_ID15;
 
DROP TABLE #SubsHierarchyOwnership;
DROP TABLE #SubsHierarchyTree;

GO

grant execute on SubsidiaryHierarchyReport to <LOGIN>
go

--END SubsidiaryHierarchyReport


-- Remove_Stock_Ticker_widget_from_Home_Page_SQL.sql modified on 02/22/2018
-- Begin delete of Stock Ticker widget
DELETE FROM WidgetAccess WHERE WidgetAccess.Widget_ID=11;
GO
DELETE FROM UserHomePageTab_Widget WHERE UserHomePageTab_Widget.Widget_ID=11;
GO
DELETE FROM Widget_Tabs WHERE Widget_Tabs.Widget_ID=11;
GO
DELETE FROM Widget WHERE Widget.Widget_ID=11;
GO
-- End delete of Stock Ticker widget


insert into DatabaseHistory values
(
  '8.11.0.08.00',
  '11-MAY-2021',
  'Suite81100600-81100800-SQL.sql',
  'Upgrades the database from 8.11.0.06.00 to 8.11.0.08.00.',
  GETDATE()
)
go